pub struct SubPath { /* private fields */ }
Non-empty collections of segments where end of each segments conisides with the start of the next one.
Whether sub-path is closed or not
First segment in the sub-path
Last segment in the sub-path
Apply transformation to the sub-path in place
Start point of the sub-path
End point of the sub-path
Bounding box of the sub-path
Create new sub-path with reversed direction
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Extends a collection with the contents of an iterator. Read more
🔬 This is a nightly-only experimental API. (extend_one)
Extends a collection with exactly one element.
🔬 This is a nightly-only experimental API. (extend_one)
Reserves capacity in a collection for the given number of additional elements. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.